=============================
hms_base, base module for HMS
=============================

This Python module is very simple and allow you to connect to the HMS network
with the protocol already implemented.

Features
========

A basic HMS microservice can do the following:

- Connect to the messaging server
- Publish a message with a topic key
- Receive and handle messages from various topic keys

And that's it. All these functions are provided by this Python module.